@@ -2,9 +2,14 @@
 #
 # Licensed under the 3-clause BSD license. See the LICENSE file.
 from . import licenses
+from .upt import Archive
+from .upt import ArchiveType
+from .upt import ArchiveUnavailable
 from .upt import Backend
 from .upt import Frontend
 from .upt import Package
 from .upt import PackageRequirement
 from .exceptions import InvalidPackageNameError
 from .exceptions import UnhandledFrontendError
+from .checksum import HashUnknown
+from .checksum import HashUnavailable
